@@ -1,4 +1,4 @@
-package Pod::Weaver::Config 4.018;
+package Pod::Weaver::Config 4.019;
 # ABSTRACT: stored configuration loader role
 
 use Moose::Role;
@@ -47,18 +47,19 @@ Pod::Weaver::Config - stored configuration loader role
 
 =head1 VERSION
 
-version 4.018
+version 4.019
 
 =head1 DESCRIPTION
 
 The config role provides some helpers for writing a configuration loader using
 the L<Config::MVP|Config::MVP> system to load and validate its configuration.
 
-=head1 PERL VERSION SUPPORT
+=head1 PERL VERSION
 
-This module has the same support period as perl itself:  it supports the two
-most recent versions of perl.  (That is, if the most recently released version
-is v5.40, then this module should work on both v5.40 and v5.38.)
+This module should work on any version of perl still receiving updates from
+the Perl 5 Porters.  This means it should work on any version of perl released
+in the last two to three years.  (That is, if the most recently released
+version is v5.40, then this module should work on both v5.40 and v5.38.)
 
 Although it may work on older versions of perl, no guarantee is made that the
 minimum required version will not be increased.  The version may be increased
@@ -75,11 +76,11 @@ will be pre-loaded with a starting section for root configuration.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@semiotic.systems>
+Ricardo SIGNES <cpan@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by Ricardo SIGNES.
+This software is copyright (c) 2023 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
