@@ -1,4 +1,4 @@
-package Pod::Weaver::Section::Collect 4.018;
+package Pod::Weaver::Section::Collect 4.019;
 # ABSTRACT: a section that gathers up specific commands
 
 use Moose;
@@ -170,7 +170,7 @@ Pod::Weaver::Section::Collect - a section that gathers up specific commands
 
 =head1 VERSION
 
-version 4.018
+version 4.019
 
 =head1 OVERVIEW
 
@@ -185,11 +185,12 @@ content, will be collected under a C<=head1 METHODS> header and placed in the
 correct location in the output stream.  Their order will be preserved as it was
 in the source document.
 
-=head1 PERL VERSION SUPPORT
+=head1 PERL VERSION
 
-This module has the same support period as perl itself:  it supports the two
-most recent versions of perl.  (That is, if the most recently released version
-is v5.40, then this module should work on both v5.40 and v5.38.)
+This module should work on any version of perl still receiving updates from
+the Perl 5 Porters.  This means it should work on any version of perl released
+in the last two to three years.  (That is, if the most recently released
+version is v5.40, then this module should work on both v5.40 and v5.38.)
 
 Although it may work on older versions of perl, no guarantee is made that the
 minimum required version will not be increased.  The version may be increased
@@ -220,11 +221,11 @@ The title of the section to be added.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@semiotic.systems>
+Ricardo SIGNES <cpan@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by Ricardo SIGNES.
+This software is copyright (c) 2023 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
