@@ -1,4 +1,4 @@
-package Pod::Weaver::Section::GenerateSection 4.018;
+package Pod::Weaver::Section::GenerateSection 4.019;
 # ABSTRACT: add pod section from an interpolated piece of text
 
 use Moose;
@@ -243,7 +243,7 @@ Pod::Weaver::Section::GenerateSection - add pod section from an interpolated pie
 
 =head1 VERSION
 
-version 4.018
+version 4.019
 
 =head1 SYNOPSIS
 
@@ -282,11 +282,12 @@ example:
   text = Also, come check out our other projects at
   text = {{$homepage}}
 
-=head1 PERL VERSION SUPPORT
+=head1 PERL VERSION
 
-This module has the same support period as perl itself:  it supports the two
-most recent versions of perl.  (That is, if the most recently released version
-is v5.40, then this module should work on both v5.40 and v5.38.)
+This module should work on any version of perl still receiving updates from
+the Perl 5 Porters.  This means it should work on any version of perl released
+in the last two to three years.  (That is, if the most recently released
+version is v5.40, then this module should work on both v5.40 and v5.38.)
 
 Although it may work on older versions of perl, no guarantee is made that the
 minimum required version will not be increased.  The version may be increased
@@ -366,11 +367,11 @@ C<< $bugtracker_email >>
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@semiotic.systems>
+Ricardo SIGNES <cpan@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by Ricardo SIGNES.
+This software is copyright (c) 2023 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
